
# Type: slot_uri


predicate of this slot for semantic web application

URI: [meta:slot_uri](https://w3id.org/biolink/biolinkml/meta/slot_uri)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
